#
# spec file for package python-django-silk
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-django-silk
Version:        5.3.1
Release:        1.4
Summary:        Profiling for the Django Framework
License:        MIT
URL:            https://github.com/jazzband/django-silk
Source:         https://files.pythonhosted.org/packages/source/d/django-silk/django_silk-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 4.2
Requires:       python-autopep8 >= 1.2.1
Requires:       python-gprof2dot >= 2017.09.19
Requires:       python-sqlparse >= 0.1.19
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 4.2}
BuildRequires:  %{python_module autopep8 >= 1.2.1}
BuildRequires:  %{python_module factory_boy >= 3.3}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module gprof2dot >= 2017.09.19}
BuildRequires:  %{python_module networkx >= 2.6}
BuildRequires:  %{python_module pydot >= 1.4}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sqlparse >= 0.1.19}
# /SECTION
%python_subpackages

%description
Profiling for the Django Framework.

%prep
%setup -n django_silk-%{version}
chmod a-x silk/static/silk/lib/*.css
chmod a-x silk/static/silk/lib/*.js

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
cd project
export DB_ENGINE=sqlite3 DB_NAME=":memory:"
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/silk
%{python_sitelib}/django_silk-%{version}.dist-info

%changelog
* Tue Nov 12 2024 Dirk Müller <dmueller@suse.com>
- update to 5.3.1:
  * Fix missing jQuery UI images (#754) @Tatsh
  * Fix swallowing exceptions when processing response in silk
    middleware (#753) @albertyw
  * Support python 3.13
  * Upgrade jQuery-UI to 1.13.2 to fix XSS vulnerability
  * Remove Django 3.2 support
  * Drop support for python 3.8
  * Update python dependencies
* Mon Oct 21 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 5.2.0:
  * Features/Enhancements:
    + Support Django 5.1
  * Fixes:
    + Fix when Session, Authentication or Message middleware are not present
    + Update 'tables_involved' property to include tables from UPDATE
    operation
    + Correct units in profiling and requests pages
  * Maintenance and Cleanup:
    + Update python dependencies
    + Refactor SQL query time calculation to use Django aggregation
- Switch to pyproject and pytest macros.
* Tue Jan 30 2024 Dirk Müller <dmueller@suse.com>
- update to 5.1.0:
  * This release includes Fix deprecation warning for
    get_storage_class #669
  * which deprecates `SILKY_STORAGE_CLASS`.  Users should instead
    use the Django `STORAGES` configuration.
  * Also, for python 3.12, the `cProfile` stdlib library cannot
    be enabled multiple times concurrently.
  * Silk will therefore skip profiling if another profile is
    already enabled.
  * Allow option to delete profiles
  * Gracefully error out when there are concurrent profilers
  * Always disable cProfile as part of cleanup
  * Fix when Session, Authentication or Message middlewares are
    not present
  * Support Django 4.2
  * Support python 3.12
  * Support Django 5
  * Remove deprecated datetime.timezone.utc
  * Derive version from importlib
* Mon Oct  2 2023 Dirk Müller <dmueller@suse.com>
- update to 5.0.4:
  * Handle case-insensitive sensitive headers (#674) @shtimn
  * Add a "pagetitle" block to Silky templates (#661) @vsajip
  * Allow to generate more informative profile file name (#638)
    @k4rl85
  * Outsource all inline scripts and styles (#635) @sgelis
  * Remove support for looking up headers on django &lt;3.2
  * Update python dependencies (#677) @albertyw
* Thu Jan 26 2023 John Vandenberg <jayvdb@gmail.com>
- Drop remove-contextlib2.patch merged upstream
- Update to v5.0.3
  * Retain ordering, view style and limit
  * prevent encoding errors in params
  * Silk fails on constraint check queries
    (Fixes compatibility with Django 4.1)
  * Add action on sql query list
  * traceback only when needed
  * Drop dependency to jinja2
- from v5.0.2
  * Fix Multipart forms and RawPostDataException
  * Decrease unnecessary database hits
  * Remove unneeded pytz package
  * Use contextlib in test_profile_parser
  * Add support for storages, that don't implement full filesystem path
* Fri Aug 12 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 5.0.1:
  * Add jquery UI 1.13.1 images and fix collectstatic
  * Drop support for Django 2.2 (EOL) (#567)
  * Added silk_request_garbage_collect command for out-of-band garbage
    collection.
  * Switch 'Apply' and 'Clear all filters' ordering
  * Make filters on Requests tab more visible
  * Add small margin for filter selects
  * Add 'Clear all filters' button
  * Add message when there are no requests to display
  * Making the error logging more accurate and explicit
  * Fixing #530 - Adding support for SILKY_EXPLAIN_FLAGS
  * Remove unused js compilation pipeline (#561)
- Add patch remove-contextlib2.patch:
  * Remove use of contextlib2.
- No longer skip Python 3.6.
* Thu May 12 2022 pgajdos@suse.com
- version update to 4.3.0
  * Jazzband: Synced file(s) with jazzband/.github by @jazzband-bot in #518
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #520
  * Fix installation instructions in README by @side2k in #521
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #523
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #524
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #526
  * Add Python 3.10 compatibility by @hramezani in #527
  * Django main by @hramezani in #528
  * Remove unneeded dependency Pygments by @jayvdb in #532
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #533
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #535
  * Replace assertDictContainsSubset by @albertyw in #536
  * Use correct db in a multi db setup by @glujan in #538
  * Update django version by @eduzen in #544
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #552
  * Some tests misusing assertTrue for comparisons fix by @code-review-doctor in #550
  * Standardize supported django versions by @albertyw in #553
  * Drop support for python 3.6 by @albertyw in #554
  * Remove duplicate requirements.txt dependencies by @albertyw in #555
  * Pin dependencies in requirements.txt by @albertyw in #556
  * Release version v4.3.0 by @albertyw in #557
- python-mock is not required for build
- deleted patches
  - 2610f91.patch (upstreamed)
* Sun Dec 26 2021 John Vandenberg <jayvdb@gmail.com>
- Replace no-longer necessary _service with PyPI tarball
- Add 2610f91.patch to fix a test incompatibility with Django 4.
- Tidy build dependencies and remove unnecessary Pygments dep.
- Upgrade to v4.2.0
  * Passed wsgi request to SILKY_PYTHON_PROFILER_FUNC
  * Added Django 3.1 & 3.2 to test matrix
  * Replace url with re_path for Django 4.0
  * Do not crash when silk app is not included in urls
  * Add the SILKY_JSON_ENSURE_ASCII configuration item to support
    Chinese
  * Add row view for requests page
  * RequestModelFactory: fallback if request body too large
  * Add query execution plan to sql_detail
  * Add Python 3.9 compatibility
  * Replace re_path with path
  * Fix transaction error for mysql
  * parse query when count joins to match only Keyword
  * fix: DB connection to ClearDB when multiple databases
  * fix: DataCollector sql_queries model not found on
    filter(request=self.request)
  * Generate missing row.css from sass
  * Filter null values from most time overall summary
  * Ensure sorting between longest requests
  * Filter null values from most db time summary
  * Ensure sorting between most db time requests
  * Temporary fix for testing Django 2.2
  * Fix egg metadata error
  * Fixed a bug that the profile tab could not be opened
    when the source code contains Japanese
  * fix incorrectly made decorator
  * Ensure sorting between most db queries requests
  * Add tests that access the actual DB
  * remove python 2 style codes from across the codebase
  * Fix broken test on Windows 10 (SQLite)
  * Remove Make Migrations
  * Add Python 3.10 compatibility
* Thu Dec  2 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Skip python 3.6 since python-networkx does not support it
* Mon May  3 2021 John Vandenberg <jayvdb@gmail.com>
- Skip Python 3.9 due to incompatibilities fixed in upcoming release
- Remove executable bit on static assets
* Mon Aug 31 2020 mcalabkova@suse.com
- Update to version 4.1.0:
  * #427 Passed wsgi request to SILKY_PYTHON_PROFILER_FUNC
  * Release 4.1.0
  * Update README.md django-silk is tested with Django 3.1
  * Make compatible with Django 3.1
  * Fix force_text RemovedInDjango40Warning
  * Extra line removed
  * 配置silk使用非'default'的数据库时Clear DB错误
  * Capture entire key name during cleansing in _mask_credentials (#414)
  * Replace the call to re.findall with re.sub in _mask_credentials so (#413)
  * Wrap re.sub() in try-except. If credentials ends with "\" (for example: "--password=123456\") re.sub() fails with error "bad escape (end of pattern)".
- Switch to obs service to silence setuptools_scm error
* Fri Apr  3 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.0.1:
  * Restructured clear db HTML #399 (nasirhjafri)
  * JS workflow cleanup #397 (nasirhjafri)
  * Refactor QA setup #393 (aleksihakli)
* Thu Feb 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.0.0:
  * Ability to clean up all requests/queries #368 (nasirhjafri)
  * Used bulk_create to save number of queries #370 (nasirhjafri)
  * Dropped Python 2 and 3.4 support #380 (munza)
  * Added Python 3.8 support #380 (nasirhjafri)
  * Removed django<2.2 support and added django 3.0 support #385 (nasirhjafri)
  * Add function support for enabling profiling #391 (tredzko)
  * Mask authorization header #376 (StefanMich)
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.0.4:
  * templates: limit select width to its container one #351 (xrmx)
  * Clean up RemovedInDjango30Warning with {%% load staticfiles %%} #353 (devmonkey22)
  * Simplify pattern masking and handle dicts #355 (Chris7)
  * Fix masking sensitive data in batch JSON request #342 (nikolaik)
  * Fix project url on PyPi #343 (luzfcb)
* Mon Apr 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.0.2:
  * Add testing support for django 2.2 #340 (mbeacom)
  * SILKY_MIDDLEWARE_CLASS option #334 (vartagg)
  * Many bugfixes
- Remove merged patches:
  * pr_333.patch
  * test-urls-auth-login-view.patch
* Tue Mar 26 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from descriptions.
* Thu Feb 21 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v3.0.1
- Use upstream pr_333.patch to fix incompatible version of gprof2dot
- Fix tests on Django 2.1 with test-urls-auth-login-view.patch
